package com.example.iplace.main.viewModel.dataView

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Settings
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.navigation.NavHostController
import com.example.iplace.R
import com.example.iplace.main.viewModel.MainViewModel
import com.example.iplace.ui.theme.brown_contrast

@Composable
fun PlaceV(navController: NavHostController) {
    val viewModel = MainViewModel()

    val headlinesOswald = FontFamily( //выбор шрифта
        Font(resId = R.font.headlines_oswald)
    )
    val basicNunitosans = FontFamily(
        Font(resId = R.font.basic_nunitosans)
    )

    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color.White)
    ) {
        Spacer(modifier = Modifier.height(20.dp))
        // Верхний блок (2/5 размера экрана)
        Box(
            modifier = Modifier
                .weight(2f)
                .background(Color.LightGray)
                .padding(16.dp)
        ) {
            // Кнопки назад и автора
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .align(Alignment.TopStart), // Выравнивание по левому верхнему углу
                horizontalArrangement = Arrangement.Start, // Выравнивание по левому краю
                verticalAlignment = Alignment.CenterVertically
            ) {
                IconButton(onClick = { navController.navigate("MenuV") }) {
                    Icon(Icons.Filled.ArrowBack, contentDescription = "Назад")
                }
                Spacer(modifier = Modifier.width(220.dp))
                Text(
                    text = "Автор",
                    fontWeight = FontWeight.Bold,
                    modifier = Modifier.padding(start = 16.dp) // Отступ от кнопки "Назад"
                )
            }

            // Блок с Название и Категория
            Column(
                modifier = Modifier
                    .align(Alignment.BottomStart) // Выравнивание по левому нижнему углу
                    .padding(16.dp) // Отступ от краев
            ) {
                Text(text = "Название")
                Spacer(modifier = Modifier.height(8.dp)) // Отступ между текстами
                Text(text = "Категория")
            }
            Button(
                onClick = { /* Обработка нажатия на фильтр */ },
                modifier = Modifier
                    .align(Alignment.BottomEnd) // Выравниваем Button по правому верхнему углу
                    .width(40.dp)
                    .height(40.dp),
                colors = ButtonDefaults.buttonColors(brown_contrast)
            ) {
                Text(text = "☆")
            }
        }

        // Остальной контент (3/5 размера экрана)
        Box(
            modifier = Modifier
                .weight(3f)
                .fillMaxSize()
                .background(Color.White)
        ) {
            Column(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(top = 10.dp),
                horizontalAlignment = Alignment.CenterHorizontally
            ) {

                Spacer(modifier = Modifier.height(10.dp))

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Описание") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
                Spacer(modifier = Modifier.height(10.dp))

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Адрес") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
                Spacer(modifier = Modifier.height(10.dp))

                Row(
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.SpaceBetween,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    OutlinedTextField(
                        value = "",
                        onValueChange = {},
                        label = { Text("Фото") },
                        modifier = Modifier
                            .height(120.dp)
                            .width(200.dp)
                            .padding(horizontal = 16.dp)
                            .clip(RoundedCornerShape(20.dp))
                    )
                    OutlinedTextField(
                        value = "",
                        onValueChange = {},
                        label = { Text("Фото") },
                        modifier = Modifier
                            .height(120.dp)
                            .width(200.dp)
                            .padding(horizontal = 16.dp)
                            .clip(RoundedCornerShape(20.dp))
                    )
                }
                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Карта") },
                    modifier = Modifier
                        .height(120.dp)
                        .width(400.dp)
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
            }
        }
    }
}