package com.example.iplace.main.viewModel.dataView

import android.net.Uri
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.KeyboardArrowDown
import androidx.compose.material.icons.filled.KeyboardArrowUp
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Card
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.asImageBitmap
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.em
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import coil.compose.rememberImagePainter
import com.example.iplace.R
import com.example.iplace.main.viewModel.MainViewModel
import com.example.iplace.main.viewModel.mainView.toBitmap
import com.example.iplace.ui.theme.beige_white
import com.example.iplace.ui.theme.brown_contrast
import java.io.IOException

@Composable
fun PolicyConditionality(navController: NavHostController) {
    val viewModel = MainViewModel()
    val headlinesOswald = FontFamily( //загрузка шрифта
        Font(resId = R.font.headlines_oswald)
    )
    val basicNunitosans = FontFamily(
        Font(resId = R.font.basic_nunitosans)
    )


    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color.White),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Spacer(modifier = Modifier.height(60.dp)) //отступ между блоками
        Text(
            text = "I.PLACE",
            fontSize = 45.sp,
            fontWeight = FontWeight.Bold,
            fontFamily = headlinesOswald
        )
        Spacer(modifier = Modifier.height(55.dp))
        Card(
            modifier = Modifier
                .width(350.dp)
                .height(700.dp)
                .clip(RoundedCornerShape(40.dp))
                .background(beige_white)
//        .alpha(0.8f) //возможная прозрачность формы
        ) {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Top,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Spacer(modifier = Modifier.height(5.dp)) // Отступ от заголовка

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = Modifier.fillMaxWidth()
                ) {
                    IconButton(onClick = { navController.navigate("selectEnter") }) {
                        Icon(
                            imageVector = Icons.Default.ArrowBack, // Или другой иконки
                            contentDescription = "Назад",
                            modifier = Modifier.padding(top = 20.dp)
                        )
                    }
                    Spacer(modifier = Modifier.width(90.dp)) // Отступ между кнопкой и текстом
                    Text(
                        text = "Политика конденфициальности",
                        fontWeight = FontWeight.Bold,
                        fontFamily = headlinesOswald,
                        modifier = Modifier.padding(top = 20.dp) // Отступ сверху
                    )
                }

                Spacer(modifier = Modifier.height(40.dp)) // Отступ от заголовка

                Text(
                    text = "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. \n" +
                            "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. \n" +
                            "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. " +
                            "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. \n" +
                            "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. \n" +
                            "Этот текст является \"рыбой\" (lorem ipsum) и не имеет смысла. Он используется для заполнения текстовых полей на макетах, чтобы показать, как будет выглядеть готовый дизайн с реальным контентом. ",
                    fontSize = 12.sp,
                    lineHeight = 1.5.em,
                    fontWeight = FontWeight.Bold,
                    fontFamily = basicNunitosans, //шрифт
                    modifier = Modifier.padding(horizontal = 20.dp) //отступ слева и справа
                )



                Spacer(modifier = Modifier.height(20.dp))

                Button(
                    onClick = { navController.navigate("profile") },
                    modifier = Modifier.width(290.dp).height(50.dp),
                    colors = ButtonDefaults.buttonColors(brown_contrast)
                ) {
                    Text(
                        text = "Соглашаюсь",
                        fontSize = 24.sp,
                        fontFamily = basicNunitosans
                    )
                }

                Spacer(modifier = Modifier.height(16.dp)) // Отступ снизу
            }
        }
    }
}