package com.example.iplace.main.viewModel.mainView

import android.net.Uri
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.KeyboardArrowDown
import androidx.compose.material.icons.filled.KeyboardArrowUp
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Card
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.asImageBitmap
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import coil.compose.rememberImagePainter
import com.android.volley.toolbox.ImageRequest
import com.example.iplace.R
import com.example.iplace.main.viewModel.MainViewModel
import com.example.iplace.ui.theme.beige_white
import com.example.iplace.ui.theme.brown_contrast
import java.io.IOException

@Composable
fun CreatingUser(navController: NavHostController) {
    val viewModel = MainViewModel()
    val headlinesOswald = FontFamily( //загрузка шрифта
        Font(resId = R.font.headlines_oswald)
    )
    val basicNunitosans = FontFamily(
        Font(resId = R.font.basic_nunitosans)
    )

    var expanded by remember { mutableStateOf(false) }
    var selectedItem by remember { mutableStateOf("") }

    var selectedImageUri by remember { mutableStateOf<Uri?>(null) }
    var imageBitmap by remember { mutableStateOf<androidx.compose.ui.graphics.ImageBitmap?>(null) }

    val context = LocalContext.current
    val launcher = rememberLauncherForActivityResult(
        contract = ActivityResultContracts.GetContent()
    ) { uri: Uri? ->
        selectedImageUri = uri
        if (uri != null) {
            try {
                val bitmap = uri.toBitmap(context)
                imageBitmap = bitmap.asImageBitmap()
            } catch (e: IOException) {
                // Обработка ошибок
            }
        }
    }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color.White),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Spacer(modifier = Modifier.height(60.dp)) //отступ между блоками
        Text(
            text = "I.PLACE",
            fontSize = 45.sp,
            fontWeight = FontWeight.Bold,
            fontFamily = headlinesOswald
        )
        Spacer(modifier = Modifier.height(55.dp))
        Card(
            modifier = Modifier
                .width(350.dp)
                .height(700.dp)
                .clip(RoundedCornerShape(40.dp))
                .background(beige_white)
//        .alpha(0.8f) //возможная прозрачность формы
        ) {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Top,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Spacer(modifier = Modifier.height(5.dp)) // Отступ от заголовка

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = Modifier.fillMaxWidth()
                ) {
                    IconButton(onClick = { navController.navigate("selectEnter") }) {
                        Icon(
                            imageVector = Icons.Default.ArrowBack, // Или другой иконки
                            contentDescription = "Назад",
                            modifier = Modifier.padding(top = 20.dp)
                        )
                    }
                    Spacer(modifier = Modifier.width(90.dp)) // Отступ между кнопкой и текстом
                    Text(
                        text = "Создание пользователя",
                        fontWeight = FontWeight.Bold,
                        fontFamily = headlinesOswald,
                        modifier = Modifier.padding(top = 20.dp) // Отступ сверху
                    )
                }

                Spacer(modifier = Modifier.height(40.dp)) // Отступ от заголовка

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Имя") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
                Spacer(modifier = Modifier.height(10.dp))
                Box(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                        .background(Color.White) // Фон выпадающего списка
                        .clickable { expanded = !expanded } // Клик для раскрытия/сворачивания
                ) {
                    // Выбранный элемент
                    Text(
                        text = selectedItem,
                        modifier = Modifier.padding(16.dp),
                        color = Color.Gray // Цвет текста выбранного элемента
                    )

                    // Иконка раскрытия/сворачивания
                    Icon(
                        imageVector = if (expanded) Icons.Filled.KeyboardArrowUp else Icons.Filled.KeyboardArrowDown,
                        contentDescription = null,
                        modifier = Modifier
                            .align(Alignment.BottomEnd)
                            .padding(16.dp)
                    )

//                    DropdownMenu(
//                        expanded = expanded,
//                        onDismissRequest = { expanded = false },
//                        modifier = Modifier
//                            .fillMaxWidth()
//                            .background(Color.White) // Фон выпадающего меню
//                    ) {
//                        // Элементы выпадающего списка
//                        listOf("Мужской", "Женский").forEach { item ->
//                            DropdownMenuItem(
//                                onClick = {
//                                    selectedItem = item
//                                    expanded = false
//                                }
//                            ) {
//                                Text(text = item)
//                            }
//                        }
//                    }
                }

                Spacer(modifier = Modifier.height(10.dp))

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Адрес") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
                Spacer(modifier = Modifier.height(10.dp))

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("Телефон") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )
                Spacer(modifier = Modifier.height(10.dp))

                OutlinedTextField(
                    value = "",
                    onValueChange = {},
                    label = { Text("О себе") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(45.dp)
                        .padding(horizontal = 16.dp)
                        .clip(RoundedCornerShape(20.dp))
                )

                Column(
//                    modifier = Modifier
//                        .fillMaxSize()
//                        .padding(16.dp),
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    Button(onClick = { launcher.launch("image/*") }) {
                        Text("Выбрать фото")
                    }
                    Spacer(modifier = Modifier.height(0.dp))
                    if (imageBitmap != null) {
                        Image(
                            painter = rememberImagePainter(
                                data = imageBitmap
                            ),
                            contentDescription = "Selected Image",
                            modifier = Modifier
                                .width(50.dp)
                                .height(50.dp)
                        )
                    } else if (selectedImageUri != null) {
//                        Image(
//                            painter = rememberImagePainter(
//                                request = ImageRequest.Builder(context)
//                                    .data(selectedImageUri)
//                                    .build()
//                            ),
//                            contentDescription = "Selected Image",
//                            modifier = Modifier
//                                .width(200.dp)
//                                .height(200.dp)
//                        )
                    } else {
                        Text("Выберите фото", fontSize = 18.sp)
                    }
                }



                Spacer(modifier = Modifier.height(20.dp))

                Button(
                    onClick = { navController.navigate("policyConditionality") },
                    modifier = Modifier.width(290.dp).height(50.dp),
                    colors = ButtonDefaults.buttonColors(brown_contrast)
                ) {
                    Text(
                        text = "Создать",
                        fontSize = 24.sp,
                        fontFamily = basicNunitosans
                    )
                }

                Spacer(modifier = Modifier.height(16.dp)) // Отступ снизу
            }
        }
    }
}

fun Uri.toBitmap(context: android.content.Context): android.graphics.Bitmap {
    val resolver = context.contentResolver
    return android.graphics.BitmapFactory.decodeStream(resolver.openInputStream(this))
}